Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_,
and this project adheres to `Semantic Versioning`_.

Unreleased
----------

`2.0`_ - 2023-05-14
-------------------

Fixed
~~~~~

* The Matrix groups and rooms threw a 404 error.
* The Matrix parent menu point was displayed even though the user had no permission to see it.

`2.0b0`_ - 2023-02-23
---------------------

This version requires AlekSIS-Core 3.0. It is incompatible with any previous
version.

Removed
~~~~~~~

* Legacy menu integration for AlekSIS-Core pre-3.0

Added
~~~~~

* Support for SPA in AlekSIS-Core 3.0

`1.0`_ - 2022-06-25
-------------------

Added
~~~~~

* Initial release.

.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html

.. _1.0: https://edugit.org/AlekSIS/Official/AlekSIS-App-Matrix/-/tags/1.0
.. _2.0b0: https://edugit.org/AlekSIS/Official/AlekSIS-App-Matrix/-/tags/2.0b0
.. _2.0: https://edugit.org/AlekSIS/Official/AlekSIS-App-Matrix/-/tags/2.0
